@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import os
 import platform
 import sys
 
@@ -32,7 +31,7 @@ class WheelDestination(SchemeDictionaryDestination):
     def write_to_fs(
         self,
         scheme: Scheme,
-        path: Path | str,
+        path: str,
         stream: BinaryIO,
         is_executable: bool,
     ) -> RecordEntry:
@@ -51,15 +50,15 @@ class WheelDestination(SchemeDictionaryDestination):
         if not parent_folder.exists():
             # Due to the parallel installation it can happen
             # that two threads try to create the directory.
-            os.makedirs(parent_folder, exist_ok=True)
+            parent_folder.mkdir(parents=True, exist_ok=True)
 
-        with open(target_path, "wb") as f:
+        with target_path.open("wb") as f:
             hash_, size = copyfileobj_with_hashing(stream, f, self.hash_algorithm)
 
         if is_executable:
             make_file_executable(target_path)
 
-        return RecordEntry(str(path), Hash(self.hash_algorithm, hash_), size)
+        return RecordEntry(path, Hash(self.hash_algorithm, hash_), size)
 
     def for_source(self, source: WheelFile) -> WheelDestination:
         scheme_dict = self.scheme_dict.copy()
@@ -91,7 +90,7 @@ class WheelInstaller:
         schemes["headers"] = schemes["include"]
 
         self._destination = WheelDestination(
-            schemes, interpreter=self._env.python, script_kind=script_kind
+            schemes, interpreter=str(self._env.python), script_kind=script_kind
         )
 
         self.invalid_wheels: dict[Path, list[str]] = {}
