@@ -12,7 +12,6 @@ from typing import TYPE_CHECKING
 
 from poetry.core.packages.package import Package
 from poetry.core.packages.utils.link import Link
-from poetry.core.toml.file import TOMLFile
 from poetry.core.vcs.git import ParsedUrl
 
 from poetry.config.config import Config
@@ -69,13 +68,6 @@ def get_dependency(
     return Factory.create_dependency(name, constraint or "*", groups=groups)
 
 
-def fixture(path: str | None = None) -> Path:
-    if path:
-        return FIXTURE_PATH / path
-    else:
-        return FIXTURE_PATH
-
-
 def copy_or_symlink(source: Path, dest: Path) -> None:
     if dest.is_symlink() or dest.is_file():
         dest.unlink()  # missing_ok is only available in Python >= 3.8
@@ -112,9 +104,11 @@ def mock_clone(
 ) -> MockDulwichRepo:
     # Checking source to determine which folder we need to copy
     parsed = ParsedUrl.parse(url)
+    assert parsed.pathname is not None
     path = re.sub(r"(.git)?$", "", parsed.pathname.lstrip("/"))
 
-    folder = Path(__file__).parent / "fixtures" / "git" / parsed.resource / path
+    assert parsed.resource is not None
+    folder = FIXTURE_PATH / "git" / parsed.resource / path
 
     if not source_root:
         source_root = Path(Config.create().get("cache-dir")) / "src"
@@ -129,8 +123,7 @@ def mock_clone(
 def mock_download(url: str, dest: Path) -> None:
     parts = urllib.parse.urlparse(url)
 
-    fixtures = Path(__file__).parent / "fixtures"
-    fixture = fixtures / parts.path.lstrip("/")
+    fixture = FIXTURE_PATH / parts.path.lstrip("/")
 
     copy_or_symlink(fixture, dest)
 
@@ -139,9 +132,9 @@ class TestExecutor(Executor):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
 
-        self._installs = []
-        self._updates = []
-        self._uninstalls = []
+        self._installs: list[Package] = []
+        self._updates: list[Package] = []
+        self._uninstalls: list[Package] = []
 
     @property
     def installations(self) -> list[Package]:
@@ -155,12 +148,14 @@ class TestExecutor(Executor):
     def removals(self) -> list[Package]:
         return self._uninstalls
 
-    def _do_execute_operation(self, operation: Operation) -> None:
-        super()._do_execute_operation(operation)
+    def _do_execute_operation(self, operation: Operation) -> int:
+        rc = super()._do_execute_operation(operation)
 
         if not operation.skipped:
             getattr(self, f"_{operation.job_type}s").append(operation.package)
 
+        return rc
+
     def _execute_install(self, operation: Operation) -> int:
         return 0
 
@@ -177,6 +172,7 @@ class PoetryTestApplication(Application):
         self._poetry = poetry
 
     def reset_poetry(self) -> None:
+        assert self._poetry is not None
         poetry = self._poetry
         self._poetry = Factory().create_poetry(self._poetry.file.path.parent)
         self._poetry.set_pool(poetry.pool)
@@ -187,13 +183,12 @@ class PoetryTestApplication(Application):
 
 
 class TestLocker(Locker):
-    def __init__(self, lock: str | Path, local_config: dict) -> None:
-        self._lock = TOMLFile(lock)
-        self._local_config = local_config
-        self._lock_data = None
-        self._content_hash = self._get_content_hash()
+    # class name begins 'Test': tell pytest that it does not contain testcases.
+    __test__ = False
+
+    def __init__(self, lock: Path, local_config: dict[str, Any]) -> None:
+        super().__init__(lock, local_config)
         self._locked = False
-        self._lock_data = None
         self._write = False
 
     def write(self, write: bool = True) -> None:
@@ -207,7 +202,7 @@ class TestLocker(Locker):
 
         return self
 
-    def mock_lock_data(self, data: dict) -> None:
+    def mock_lock_data(self, data: dict[str, Any]) -> None:
         self.locked()
 
         self._lock_data = data
@@ -262,14 +257,16 @@ def isolated_environment(
 def make_entry_point_from_plugin(
     name: str, cls: type[Any], dist: metadata.Distribution | None = None
 ) -> metadata.EntryPoint:
+    group: str | None = getattr(cls, "group", None)
     ep = metadata.EntryPoint(
         name=name,
-        group=getattr(cls, "group", None),
+        group=group,  # type: ignore[arg-type]
         value=f"{cls.__module__}:{cls.__name__}",
     )
 
     if dist:
-        return ep._for(dist)
+        ep = ep._for(dist)  # type: ignore[attr-defined,no-untyped-call]
+        return ep
 
     return ep
 
@@ -306,7 +303,7 @@ def flatten_dict(obj: Mapping[str, Any], delimiter: str = ".") -> Mapping[str, A
         :return:  dict
         """
         if isinstance(obj, dict):
-            for key in obj.keys():
+            for key in obj:
                 for leaf in recurse_keys(obj[key]):
                     leaf_path, leaf_value = leaf
                     leaf_path.insert(0, key)
