@@ -32,11 +32,15 @@ from poetry.installation.operations import Uninstall
 from poetry.installation.operations import Update
 from poetry.installation.wheel_installer import WheelInstaller
 from poetry.repositories.repository_pool import RepositoryPool
+from poetry.utils.cache import ArtifactCache
 from poetry.utils.env import MockEnv
+from poetry.vcs.git.backend import Git
 from tests.repositories.test_pypi_repository import MockRepository
 
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator
+
     import httpretty
 
     from httpretty.core import HTTPrettyRequest
@@ -80,20 +84,23 @@ class Chef(BaseChef):
             wheel = self._directory_wheels.pop(0)
             self._directory_wheels.append(wheel)
 
-            return wheel
+            destination.mkdir(parents=True, exist_ok=True)
+            dst_wheel = destination / wheel.name
+            shutil.copyfile(wheel, dst_wheel)
+            return dst_wheel
 
         return super()._prepare(directory, destination, editable=editable)
 
 
 @pytest.fixture
-def env(tmp_dir: str) -> MockEnv:
-    path = Path(tmp_dir) / ".venv"
+def env(tmp_path: Path) -> MockEnv:
+    path = tmp_path / ".venv"
     path.mkdir(parents=True)
 
     return MockEnv(path=path, is_venv=True)
 
 
-@pytest.fixture()
+@pytest.fixture
 def io() -> BufferedIO:
     io = BufferedIO()
     io.output.formatter.set_style("c1_dark", Style("cyan", options=["dark"]))
@@ -104,7 +111,7 @@ def io() -> BufferedIO:
     return io
 
 
-@pytest.fixture()
+@pytest.fixture
 def io_decorated() -> BufferedIO:
     io = BufferedIO(decorated=True)
     io.output.formatter.set_style("c1", Style("cyan"))
@@ -113,14 +120,14 @@ def io_decorated() -> BufferedIO:
     return io
 
 
-@pytest.fixture()
+@pytest.fixture
 def io_not_decorated() -> BufferedIO:
     io = BufferedIO(decorated=False)
 
     return io
 
 
-@pytest.fixture()
+@pytest.fixture
 def pool() -> RepositoryPool:
     pool = RepositoryPool()
     pool.add_repository(MockRepository())
@@ -128,13 +135,13 @@ def pool() -> RepositoryPool:
     return pool
 
 
-@pytest.fixture()
+@pytest.fixture
 def mock_file_downloads(
     http: type[httpretty.httpretty], fixture_dir: FixtureDirGetter
 ) -> None:
     def callback(
         request: HTTPrettyRequest, uri: str, headers: dict[str, Any]
-    ) -> list[int | dict[str, Any] | str]:
+    ) -> list[int | dict[str, Any] | bytes]:
         name = Path(urlparse(uri).path).name
 
         fixture = Path(__file__).parent.parent.joinpath(
@@ -145,8 +152,8 @@ def mock_file_downloads(
             fixture = fixture_dir("distributions") / name
 
             if not fixture.exists():
-                fixture = Path(__file__).parent.parent.joinpath(
-                    "fixtures/distributions/demo-0.1.0-py2.py3-none-any.whl"
+                fixture = (
+                    fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
                 )
 
         return [200, headers, fixture.read_bytes()]
@@ -158,33 +165,23 @@ def mock_file_downloads(
     )
 
 
-@pytest.fixture()
-def copy_wheel(tmp_dir: Path) -> Callable[[], Path]:
+@pytest.fixture
+def copy_wheel(tmp_path: Path, fixture_dir: FixtureDirGetter) -> Callable[[], Path]:
     def _copy_wheel() -> Path:
         tmp_name = tempfile.mktemp()
-        Path(tmp_dir).joinpath(tmp_name).mkdir()
+        (tmp_path / tmp_name).mkdir()
 
         shutil.copyfile(
-            Path(__file__)
-            .parent.parent.joinpath(
-                "fixtures/distributions/demo-0.1.2-py2.py3-none-any.whl"
-            )
-            .as_posix(),
-            Path(tmp_dir)
-            .joinpath(tmp_name)
-            .joinpath("demo-0.1.2-py2.py3-none-any.whl")
-            .as_posix(),
-        )
-
-        return (
-            Path(tmp_dir).joinpath(tmp_name).joinpath("demo-0.1.2-py2.py3-none-any.whl")
+            fixture_dir("distributions") / "demo-0.1.2-py2.py3-none-any.whl",
+            tmp_path / tmp_name / "demo-0.1.2-py2.py3-none-any.whl",
         )
+        return tmp_path / tmp_name / "demo-0.1.2-py2.py3-none-any.whl"
 
     return _copy_wheel
 
 
-@pytest.fixture()
-def wheel(copy_wheel: Callable[[], Path]) -> Path:
+@pytest.fixture
+def wheel(copy_wheel: Callable[[], Path]) -> Iterator[Path]:
     archive = copy_wheel()
 
     yield archive
@@ -198,17 +195,19 @@ def test_execute_executes_a_batch_of_operations(
     config: Config,
     pool: RepositoryPool,
     io: BufferedIO,
-    tmp_dir: str,
+    tmp_path: Path,
     mock_file_downloads: None,
     env: MockEnv,
     copy_wheel: Callable[[], Path],
-):
+    fixture_dir: FixtureDirGetter,
+) -> None:
     wheel_install = mocker.patch.object(WheelInstaller, "install")
 
-    config.merge({"cache-dir": tmp_dir})
+    config.merge({"cache-dir": str(tmp_path)})
+    artifact_cache = ArtifactCache(cache_dir=config.artifacts_cache_directory)
 
     prepare_spy = mocker.spy(Chef, "_prepare")
-    chef = Chef(config, env, Factory.create_pool(config))
+    chef = Chef(artifact_cache, env, Factory.create_pool(config))
     chef.set_directory_wheel([copy_wheel(), copy_wheel()])
     chef.set_sdist_wheel(copy_wheel())
 
@@ -221,10 +220,7 @@ def test_execute_executes_a_batch_of_operations(
         "demo",
         "0.1.0",
         source_type="file",
-        source_url=Path(__file__)
-        .parent.parent.joinpath(
-            "fixtures/distributions/demo-0.1.0-py2.py3-none-any.whl"
-        )
+        source_url=(fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl")
         .resolve()
         .as_posix(),
     )
@@ -233,10 +229,7 @@ def test_execute_executes_a_batch_of_operations(
         "simple-project",
         "1.2.3",
         source_type="directory",
-        source_url=Path(__file__)
-        .parent.parent.joinpath("fixtures/simple_project")
-        .resolve()
-        .as_posix(),
+        source_url=fixture_dir("simple_project").resolve().as_posix(),
     )
 
     git_package = Package(
@@ -271,9 +264,9 @@ Package operations: 4 installs, 1 update, 1 removal
   • Installing demo (0.1.0 master)
 """
 
-    expected = set(expected.splitlines())
-    output = set(io.fetch_output().splitlines())
-    assert output == expected
+    expected_lines = set(expected.splitlines())
+    output_lines = set(io.fetch_output().splitlines())
+    assert output_lines == expected_lines
     assert wheel_install.call_count == 5
     # Two pip uninstalls: one for the remove operation one for the update operation
     assert len(env.executed) == 2
@@ -281,8 +274,8 @@ Package operations: 4 installs, 1 update, 1 removal
 
     assert prepare_spy.call_count == 2
     assert prepare_spy.call_args_list == [
-        mocker.call(chef, mocker.ANY, mocker.ANY, editable=False),
-        mocker.call(chef, mocker.ANY, mocker.ANY, editable=True),
+        mocker.call(chef, mocker.ANY, destination=mocker.ANY, editable=False),
+        mocker.call(chef, mocker.ANY, destination=mocker.ANY, editable=True),
     ]
 
 
@@ -313,13 +306,13 @@ def test_execute_prints_warning_for_yanked_package(
     config: Config,
     pool: RepositoryPool,
     io: BufferedIO,
-    tmp_dir: str,
+    tmp_path: Path,
     mock_file_downloads: None,
     env: MockEnv,
     operations: list[Operation],
     has_warning: bool,
-):
-    config.merge({"cache-dir": tmp_dir})
+) -> None:
+    config.merge({"cache-dir": str(tmp_path)})
 
     executor = Executor(env, pool, config, io)
 
@@ -346,11 +339,11 @@ def test_execute_prints_warning_for_invalid_wheels(
     config: Config,
     pool: RepositoryPool,
     io: BufferedIO,
-    tmp_dir: str,
+    tmp_path: Path,
     mock_file_downloads: None,
     env: MockEnv,
-):
-    config.merge({"cache-dir": tmp_dir})
+) -> None:
+    config.merge({"cache-dir": str(tmp_path)})
 
     executor = Executor(env, pool, config, io)
 
@@ -408,7 +401,7 @@ def test_execute_shows_skipped_operations_if_verbose(
     io: BufferedIO,
     config_cache_dir: Path,
     env: MockEnv,
-):
+) -> None:
     config.merge({"cache-dir": config_cache_dir.as_posix()})
 
     executor = Executor(env, pool, config, io)
@@ -436,7 +429,7 @@ def test_execute_should_show_errors(
     mocker: MockerFixture,
     io: BufferedIO,
     env: MockEnv,
-):
+) -> None:
     executor = Executor(env, pool, config, io)
     executor.verbose()
 
@@ -461,11 +454,11 @@ def test_execute_works_with_ansi_output(
     config: Config,
     pool: RepositoryPool,
     io_decorated: BufferedIO,
-    tmp_dir: str,
+    tmp_path: Path,
     mock_file_downloads: None,
     env: MockEnv,
-):
-    config.merge({"cache-dir": tmp_dir})
+) -> None:
+    config.merge({"cache-dir": str(tmp_path)})
 
     executor = Executor(env, pool, config, io_decorated)
 
@@ -498,11 +491,11 @@ def test_execute_works_with_no_ansi_output(
     config: Config,
     pool: RepositoryPool,
     io_not_decorated: BufferedIO,
-    tmp_dir: str,
+    tmp_path: Path,
     mock_file_downloads: None,
     env: MockEnv,
-):
-    config.merge({"cache-dir": tmp_dir})
+) -> None:
+    config.merge({"cache-dir": str(tmp_path)})
 
     executor = Executor(env, pool, config, io_not_decorated)
 
@@ -517,9 +510,9 @@ Package operations: 1 install, 0 updates, 0 removals
 
   • Installing cleo (1.0.0a5)
 """
-    expected = set(expected.splitlines())
-    output = set(io_not_decorated.fetch_output().splitlines())
-    assert output == expected
+    expected_lines = set(expected.splitlines())
+    output_lines = set(io_not_decorated.fetch_output().splitlines())
+    assert output_lines == expected_lines
     assert return_code == 0
 
 
@@ -529,7 +522,7 @@ def test_execute_should_show_operation_as_cancelled_on_subprocess_keyboard_inter
     mocker: MockerFixture,
     io: BufferedIO,
     env: MockEnv,
-):
+) -> None:
     executor = Executor(env, pool, config, io)
     executor.verbose()
 
@@ -554,7 +547,7 @@ def test_execute_should_gracefully_handle_io_error(
     mocker: MockerFixture,
     io: BufferedIO,
     env: MockEnv,
-):
+) -> None:
     executor = Executor(env, pool, config, io)
     executor.verbose()
 
@@ -582,31 +575,30 @@ Package operations: 1 install, 0 updates, 0 removals
 def test_executor_should_delete_incomplete_downloads(
     config: Config,
     io: BufferedIO,
-    tmp_dir: str,
+    tmp_path: Path,
     mocker: MockerFixture,
     pool: RepositoryPool,
     mock_file_downloads: None,
     env: MockEnv,
-):
-    fixture = Path(__file__).parent.parent.joinpath(
-        "fixtures/distributions/demo-0.1.0-py2.py3-none-any.whl"
-    )
-    destination_fixture = Path(tmp_dir) / "tomlkit-0.5.3-py2.py3-none-any.whl"
+    fixture_dir: FixtureDirGetter,
+) -> None:
+    fixture = fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
+    destination_fixture = tmp_path / "tomlkit-0.5.3-py2.py3-none-any.whl"
     shutil.copyfile(str(fixture), str(destination_fixture))
     mocker.patch(
         "poetry.installation.executor.Executor._download_archive",
         side_effect=Exception("Download error"),
     )
     mocker.patch(
-        "poetry.installation.chef.Chef.get_cached_archive_for_link",
-        side_effect=lambda link, strict: None,
+        "poetry.installation.executor.ArtifactCache.get_cached_archive_for_link",
+        return_value=None,
     )
     mocker.patch(
-        "poetry.installation.chef.Chef.get_cache_directory_for_link",
-        return_value=Path(tmp_dir),
+        "poetry.installation.executor.ArtifactCache.get_cache_directory_for_link",
+        return_value=tmp_path,
     )
 
-    config.merge({"cache-dir": tmp_dir})
+    config.merge({"cache-dir": str(tmp_path)})
 
     executor = Executor(env, pool, config, io)
 
@@ -618,7 +610,7 @@ def test_executor_should_delete_incomplete_downloads(
 
 def verify_installed_distribution(
     venv: VirtualEnv, package: Package, url_reference: dict[str, Any] | None = None
-):
+) -> None:
     distributions = list(venv.site_packages.distributions(name=package.name))
     assert len(distributions) == 1
 
@@ -627,10 +619,14 @@ def verify_installed_distribution(
     assert metadata["Name"] == package.name
     assert metadata["Version"] == package.version.text
 
-    direct_url_file = distribution._path.joinpath("direct_url.json")
+    direct_url_file = distribution._path.joinpath(  # type: ignore[attr-defined]
+        "direct_url.json"
+    )
 
     if url_reference is not None:
-        record_file = distribution._path.joinpath("RECORD")
+        record_file = distribution._path.joinpath(  # type: ignore[attr-defined]
+            "RECORD"
+        )
         with open(record_file, encoding="utf-8", newline="") as f:
             reader = csv.reader(f)
             rows = list(reader)
@@ -665,7 +661,7 @@ def test_executor_should_not_write_pep610_url_references_for_cached_package(
     pool: RepositoryPool,
     config: Config,
     io: BufferedIO,
-):
+) -> None:
     link_cached = fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
     package.files = [
         {
@@ -681,18 +677,17 @@ def test_executor_should_not_write_pep610_url_references_for_cached_package(
     executor = Executor(tmp_venv, pool, config, io)
     executor.execute([Install(package)])
     verify_installed_distribution(tmp_venv, package)
+    assert link_cached.exists(), "cached file should not be deleted"
 
 
 def test_executor_should_write_pep610_url_references_for_wheel_files(
-    tmp_venv: VirtualEnv, pool: RepositoryPool, config: Config, io: BufferedIO
-):
-    url = (
-        Path(__file__)
-        .parent.parent.joinpath(
-            "fixtures/distributions/demo-0.1.0-py2.py3-none-any.whl"
-        )
-        .resolve()
-    )
+    tmp_venv: VirtualEnv,
+    pool: RepositoryPool,
+    config: Config,
+    io: BufferedIO,
+    fixture_dir: FixtureDirGetter,
+) -> None:
+    url = (fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl").resolve()
     package = Package("demo", "0.1.0", source_type="file", source_url=url.as_posix())
     # Set package.files so the executor will attempt to hash the package
     package.files = [
@@ -715,16 +710,17 @@ def test_executor_should_write_pep610_url_references_for_wheel_files(
         "url": url.as_uri(),
     }
     verify_installed_distribution(tmp_venv, package, expected_url_reference)
+    assert url.exists(), "source file should not be deleted"
 
 
 def test_executor_should_write_pep610_url_references_for_non_wheel_files(
-    tmp_venv: VirtualEnv, pool: RepositoryPool, config: Config, io: BufferedIO
-):
-    url = (
-        Path(__file__)
-        .parent.parent.joinpath("fixtures/distributions/demo-0.1.0.tar.gz")
-        .resolve()
-    )
+    tmp_venv: VirtualEnv,
+    pool: RepositoryPool,
+    config: Config,
+    io: BufferedIO,
+    fixture_dir: FixtureDirGetter,
+) -> None:
+    url = (fixture_dir("distributions") / "demo-0.1.0.tar.gz").resolve()
     package = Package("demo", "0.1.0", source_type="file", source_url=url.as_posix())
     # Set package.files so the executor will attempt to hash the package
     package.files = [
@@ -747,26 +743,27 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_files(
         "url": url.as_uri(),
     }
     verify_installed_distribution(tmp_venv, package, expected_url_reference)
+    assert url.exists(), "source file should not be deleted"
 
 
 def test_executor_should_write_pep610_url_references_for_directories(
     tmp_venv: VirtualEnv,
     pool: RepositoryPool,
     config: Config,
+    artifact_cache: ArtifactCache,
     io: BufferedIO,
     wheel: Path,
-):
-    url = (
-        Path(__file__)
-        .parent.parent.joinpath("fixtures/git/github.com/demo/demo")
-        .resolve()
-    )
+    fixture_dir: FixtureDirGetter,
+    mocker: MockerFixture,
+) -> None:
+    url = (fixture_dir("git") / "github.com" / "demo" / "demo").resolve()
     package = Package(
         "demo", "0.1.2", source_type="directory", source_url=url.as_posix()
     )
 
-    chef = Chef(config, tmp_venv, Factory.create_pool(config))
+    chef = Chef(artifact_cache, tmp_venv, Factory.create_pool(config))
     chef.set_directory_wheel(wheel)
+    prepare_spy = mocker.spy(chef, "prepare")
 
     executor = Executor(tmp_venv, pool, config, io)
     executor._chef = chef
@@ -774,20 +771,20 @@ def test_executor_should_write_pep610_url_references_for_directories(
     verify_installed_distribution(
         tmp_venv, package, {"dir_info": {}, "url": url.as_uri()}
     )
+    assert not prepare_spy.spy_return.exists(), "archive not cleaned up"
 
 
 def test_executor_should_write_pep610_url_references_for_editable_directories(
     tmp_venv: VirtualEnv,
     pool: RepositoryPool,
     config: Config,
+    artifact_cache: ArtifactCache,
     io: BufferedIO,
     wheel: Path,
-):
-    url = (
-        Path(__file__)
-        .parent.parent.joinpath("fixtures/git/github.com/demo/demo")
-        .resolve()
-    )
+    fixture_dir: FixtureDirGetter,
+    mocker: MockerFixture,
+) -> None:
+    url = (fixture_dir("git") / "github.com" / "demo" / "demo").resolve()
     package = Package(
         "demo",
         "0.1.2",
@@ -796,8 +793,9 @@ def test_executor_should_write_pep610_url_references_for_editable_directories(
         develop=True,
     )
 
-    chef = Chef(config, tmp_venv, Factory.create_pool(config))
+    chef = Chef(artifact_cache, tmp_venv, Factory.create_pool(config))
     chef.set_directory_wheel(wheel)
+    prepare_spy = mocker.spy(chef, "prepare")
 
     executor = Executor(tmp_venv, pool, config, io)
     executor._chef = chef
@@ -805,6 +803,7 @@ def test_executor_should_write_pep610_url_references_for_editable_directories(
     verify_installed_distribution(
         tmp_venv, package, {"dir_info": {"editable": True}, "url": url.as_uri()}
     )
+    assert not prepare_spy.spy_return.exists(), "archive not cleaned up"
 
 
 @pytest.mark.parametrize("is_artifact_cached", [False, True])
@@ -817,11 +816,11 @@ def test_executor_should_write_pep610_url_references_for_wheel_urls(
     mocker: MockerFixture,
     fixture_dir: FixtureDirGetter,
     is_artifact_cached: bool,
-):
+) -> None:
     if is_artifact_cached:
         link_cached = fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
         mocker.patch(
-            "poetry.installation.chef.Chef.get_cached_archive_for_link",
+            "poetry.installation.executor.ArtifactCache.get_cached_archive_for_link",
             return_value=link_cached,
         )
     download_spy = mocker.spy(Executor, "_download_archive")
@@ -857,9 +856,11 @@ def test_executor_should_write_pep610_url_references_for_wheel_urls(
     if is_artifact_cached:
         download_spy.assert_not_called()
     else:
+        assert package.source_url is not None
         download_spy.assert_called_once_with(
             mocker.ANY, operation, Link(package.source_url)
         )
+        assert download_spy.spy_return.exists(), "cached file should not be deleted"
 
 
 @pytest.mark.parametrize(
@@ -888,7 +889,7 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_urls(
     is_wheel_cached: bool,
     expect_artifact_building: bool,
     expect_artifact_download: bool,
-):
+) -> None:
     built_wheel = fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
     mock_prepare = mocker.patch(
         "poetry.installation.chef.Chef._prepare",
@@ -900,7 +901,9 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_urls(
         cached_sdist = fixture_dir("distributions") / "demo-0.1.0.tar.gz"
         cached_wheel = fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl"
 
-        def mock_get_cached_archive_for_link_func(_: Link, strict: bool):
+        def mock_get_cached_archive_for_link_func(
+            _: Link, *, strict: bool, **__: Any
+        ) -> Path | None:
             if is_wheel_cached and not strict:
                 return cached_wheel
             if is_sdist_cached:
@@ -908,7 +911,7 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_urls(
             return None
 
         mocker.patch(
-            "poetry.installation.chef.Chef.get_cached_archive_for_link",
+            "poetry.installation.executor.ArtifactCache.get_cached_archive_for_link",
             side_effect=mock_get_cached_archive_for_link_func,
         )
 
@@ -947,32 +950,51 @@ def test_executor_should_write_pep610_url_references_for_non_wheel_urls(
         mock_prepare.assert_not_called()
 
     if expect_artifact_download:
+        assert package.source_url is not None
         download_spy.assert_called_once_with(
             mocker.ANY, operation, Link(package.source_url)
         )
+        assert download_spy.spy_return.exists(), "cached file should not be deleted"
     else:
         download_spy.assert_not_called()
 
 
+@pytest.mark.parametrize("is_artifact_cached", [False, True])
 def test_executor_should_write_pep610_url_references_for_git(
     tmp_venv: VirtualEnv,
     pool: RepositoryPool,
     config: Config,
+    artifact_cache: ArtifactCache,
     io: BufferedIO,
     mock_file_downloads: None,
     wheel: Path,
-):
+    mocker: MockerFixture,
+    fixture_dir: FixtureDirGetter,
+    is_artifact_cached: bool,
+) -> None:
+    if is_artifact_cached:
+        link_cached = fixture_dir("distributions") / "demo-0.1.2-py2.py3-none-any.whl"
+        mocker.patch(
+            "poetry.installation.executor.ArtifactCache.get_cached_archive_for_git",
+            return_value=link_cached,
+        )
+    clone_spy = mocker.spy(Git, "clone")
+
+    source_resolved_reference = "123456"
+    source_url = "https://github.com/demo/demo.git"
+
     package = Package(
         "demo",
         "0.1.2",
         source_type="git",
         source_reference="master",
-        source_resolved_reference="123456",
-        source_url="https://github.com/demo/demo.git",
+        source_resolved_reference=source_resolved_reference,
+        source_url=source_url,
     )
 
-    chef = Chef(config, tmp_venv, Factory.create_pool(config))
+    chef = Chef(artifact_cache, tmp_venv, Factory.create_pool(config))
     chef.set_directory_wheel(wheel)
+    prepare_spy = mocker.spy(chef, "prepare")
 
     executor = Executor(tmp_venv, pool, config, io)
     executor._chef = chef
@@ -990,12 +1012,72 @@ def test_executor_should_write_pep610_url_references_for_git(
         },
     )
 
+    if is_artifact_cached:
+        clone_spy.assert_not_called()
+        prepare_spy.assert_not_called()
+    else:
+        clone_spy.assert_called_once_with(
+            url=source_url, source_root=mocker.ANY, revision=source_resolved_reference
+        )
+        prepare_spy.assert_called_once()
+        assert prepare_spy.spy_return.exists(), "cached file should not be deleted"
+        assert (prepare_spy.spy_return.parent / ".created_from_git_dependency").exists()
+
+
+def test_executor_should_write_pep610_url_references_for_editable_git(
+    tmp_venv: VirtualEnv,
+    pool: RepositoryPool,
+    config: Config,
+    artifact_cache: ArtifactCache,
+    io: BufferedIO,
+    mock_file_downloads: None,
+    wheel: Path,
+    mocker: MockerFixture,
+    fixture_dir: FixtureDirGetter,
+) -> None:
+    source_resolved_reference = "123456"
+    source_url = "https://github.com/demo/demo.git"
+
+    package = Package(
+        "demo",
+        "0.1.2",
+        source_type="git",
+        source_reference="master",
+        source_resolved_reference=source_resolved_reference,
+        source_url=source_url,
+        develop=True,
+    )
+
+    chef = Chef(artifact_cache, tmp_venv, Factory.create_pool(config))
+    chef.set_directory_wheel(wheel)
+    prepare_spy = mocker.spy(chef, "prepare")
+    cache_spy = mocker.spy(artifact_cache, "get_cached_archive_for_git")
+
+    executor = Executor(tmp_venv, pool, config, io)
+    executor._chef = chef
+    executor.execute([Install(package)])
+    assert package.source_url is not None
+    verify_installed_distribution(
+        tmp_venv,
+        package,
+        {
+            "dir_info": {"editable": True},
+            "url": Path(package.source_url).as_uri(),
+        },
+    )
+
+    cache_spy.assert_not_called()
+    prepare_spy.assert_called_once()
+    assert not prepare_spy.spy_return.exists(), "editable git should not be cached"
+    assert not (prepare_spy.spy_return.parent / ".created_from_git_dependency").exists()
+
 
 def test_executor_should_append_subdirectory_for_git(
     mocker: MockerFixture,
     tmp_venv: VirtualEnv,
     pool: RepositoryPool,
     config: Config,
+    artifact_cache: ArtifactCache,
     io: BufferedIO,
     mock_file_downloads: None,
     wheel: Path,
@@ -1010,7 +1092,7 @@ def test_executor_should_append_subdirectory_for_git(
         source_subdirectory="two",
     )
 
-    chef = Chef(config, tmp_venv, Factory.create_pool(config))
+    chef = Chef(artifact_cache, tmp_venv, Factory.create_pool(config))
     chef.set_directory_wheel(wheel)
     spy = mocker.spy(chef, "prepare")
 
@@ -1026,10 +1108,11 @@ def test_executor_should_write_pep610_url_references_for_git_with_subdirectories
     tmp_venv: VirtualEnv,
     pool: RepositoryPool,
     config: Config,
+    artifact_cache: ArtifactCache,
     io: BufferedIO,
     mock_file_downloads: None,
     wheel: Path,
-):
+) -> None:
     package = Package(
         "demo",
         "0.1.2",
@@ -1040,7 +1123,7 @@ def test_executor_should_write_pep610_url_references_for_git_with_subdirectories
         source_subdirectory="two",
     )
 
-    chef = Chef(config, tmp_venv, Factory.create_pool(config))
+    chef = Chef(artifact_cache, tmp_venv, Factory.create_pool(config))
     chef.set_directory_wheel(wheel)
 
     executor = Executor(tmp_venv, pool, config, io)
@@ -1082,7 +1165,7 @@ def test_executor_should_be_initialized_with_correct_workers(
     cpu_count: int | None,
     side_effect: Exception | None,
     expected_workers: int,
-):
+) -> None:
     config.merge({"installer": {"max-workers": max_workers}})
 
     mocker.patch("os.cpu_count", return_value=cpu_count, side_effect=side_effect)
@@ -1097,10 +1180,11 @@ def test_executor_fallback_on_poetry_create_error_without_wheel_installer(
     config: Config,
     pool: RepositoryPool,
     io: BufferedIO,
-    tmp_dir: str,
+    tmp_path: Path,
     mock_file_downloads: None,
     env: MockEnv,
-):
+    fixture_dir: FixtureDirGetter,
+) -> None:
     mock_pip_install = mocker.patch("poetry.installation.executor.pip_install")
     mock_sdist_builder = mocker.patch("poetry.core.masonry.builders.sdist.SdistBuilder")
     mock_editable_builder = mocker.patch(
@@ -1112,7 +1196,7 @@ def test_executor_fallback_on_poetry_create_error_without_wheel_installer(
 
     config.merge(
         {
-            "cache-dir": tmp_dir,
+            "cache-dir": str(tmp_path),
             "installer": {"modern-installation": False},
         }
     )
@@ -1123,10 +1207,7 @@ def test_executor_fallback_on_poetry_create_error_without_wheel_installer(
         "simple-project",
         "1.2.3",
         source_type="directory",
-        source_url=Path(__file__)
-        .parent.parent.joinpath("fixtures/simple_project")
-        .resolve()
-        .as_posix(),
+        source_url=fixture_dir("simple_project").resolve().as_posix(),
     )
 
     return_code = executor.execute(
@@ -1141,9 +1222,9 @@ Package operations: 1 install, 0 updates, 0 removals
   • Installing simple-project (1.2.3 {directory_package.source_url})
 """
 
-    expected = set(expected.splitlines())
-    output = set(io.fetch_output().splitlines())
-    assert output == expected
+    expected_lines = set(expected.splitlines())
+    output_lines = set(io.fetch_output().splitlines())
+    assert output_lines == expected_lines
     assert return_code == 0
     assert mock_create_poetry.call_count == 1
     assert mock_sdist_builder.call_count == 0
@@ -1162,9 +1243,9 @@ def test_build_backend_errors_are_reported_correctly_if_caused_by_subprocess(
     config: Config,
     pool: RepositoryPool,
     io: BufferedIO,
-    tmp_dir: str,
     mock_file_downloads: None,
     env: MockEnv,
+    fixture_dir: FixtureDirGetter,
 ) -> None:
     error = BuildBackendException(
         CalledProcessError(1, ["pip"], output=b"Error on stdout")
@@ -1180,20 +1261,13 @@ def test_build_backend_errors_are_reported_correctly_if_caused_by_subprocess(
         package_name,
         package_version,
         source_type="directory",
-        source_url=Path(__file__)
-        .parent.parent.joinpath("fixtures/simple_project")
-        .resolve()
-        .as_posix(),
+        source_url=fixture_dir("simple_project").resolve().as_posix(),
         develop=editable,
     )
     # must not be included in the error message
     directory_package.python_versions = ">=3.7"
 
-    return_code = executor.execute(
-        [
-            Install(directory_package),
-        ]
-    )
+    return_code = executor.execute([Install(directory_package)])
 
     assert return_code == 1
 
@@ -1211,6 +1285,7 @@ Package operations: 1 install, 0 updates, 0 removals
   Error on stdout
 """
 
+    assert directory_package.source_url is not None
     if editable:
         pip_command = "pip wheel --use-pep517 --editable"
         requirement = directory_package.source_url
@@ -1230,11 +1305,51 @@ PEP 517 builds. You can verify this by running '{pip_command} "{requirement}"'.
     assert output.endswith(expected_end)
 
 
+@pytest.mark.parametrize("encoding", ["utf-8", "latin-1"])
+@pytest.mark.parametrize("stderr", [None, "Errör on stderr"])
+def test_build_backend_errors_are_reported_correctly_if_caused_by_subprocess_encoding(
+    encoding: str,
+    stderr: str | None,
+    mocker: MockerFixture,
+    config: Config,
+    pool: RepositoryPool,
+    io: BufferedIO,
+    mock_file_downloads: None,
+    env: MockEnv,
+    fixture_dir: FixtureDirGetter,
+) -> None:
+    """Test that the output of the subprocess is decoded correctly."""
+    stdout = "Errör on stdout"
+    error = BuildBackendException(
+        CalledProcessError(
+            1,
+            ["pip"],
+            output=stdout.encode(encoding),
+            stderr=stderr.encode(encoding) if stderr else None,
+        )
+    )
+    mocker.patch.object(ProjectBuilder, "get_requires_for_build", side_effect=error)
+    io.set_verbosity(Verbosity.NORMAL)
+
+    executor = Executor(env, pool, config, io)
+
+    directory_package = Package(
+        "simple-project",
+        "1.2.3",
+        source_type="directory",
+        source_url=fixture_dir("simple_project").resolve().as_posix(),
+    )
+
+    return_code = executor.execute([Install(directory_package)])
+
+    assert return_code == 1
+    assert (stderr or stdout) in io.fetch_output()
+
+
 def test_build_system_requires_not_available(
     config: Config,
     pool: RepositoryPool,
     io: BufferedIO,
-    tmp_dir: str,
     mock_file_downloads: None,
     env: MockEnv,
     fixture_dir: FixtureDirGetter,
