@@ -1,12 +1,13 @@
 from __future__ import annotations
 
-from pathlib import Path
 from subprocess import CalledProcessError
 from typing import TYPE_CHECKING
+from typing import Any
 
 import pytest
 
 from cleo.io.null_io import NullIO
+from packaging.utils import canonicalize_name
 from poetry.core.packages.dependency import Dependency
 from poetry.core.packages.directory_dependency import DirectoryDependency
 from poetry.core.packages.file_dependency import FileDependency
@@ -29,12 +30,14 @@ from tests.helpers import get_dependency
 if TYPE_CHECKING:
     from pytest_mock import MockerFixture
 
+    from tests.types import FixtureDirGetter
+
 
 SOME_URL = "https://example.com/path.tar.gz"
 
 
 class MockEnv(BaseMockEnv):
-    def run(self, bin: str, *args: str) -> None:
+    def run(self, bin: str, *args: str, **kwargs: Any) -> str:
         raise EnvCommandError(CalledProcessError(1, "python", output=""))
 
 
@@ -93,17 +96,7 @@ def test_search_for(
     repository.add_package(foo2a)
     repository.add_package(foo2)
     repository.add_package(foo3a)
-    # TODO: remove workaround when poetry-core with
-    #       https://github.com/python-poetry/poetry-core/pull/543 is available
-    if str(dependency.constraint) == ">=1a":
-        result = provider.search_for(dependency)
-        assert result == expected or result == [
-            Package("foo", "3a"),
-            Package("foo", "2"),
-            Package("foo", "2a"),
-            Package("foo", "1"),
-        ]
-        return
+
     assert provider.search_for(dependency) == expected
 
 
@@ -167,7 +160,7 @@ def test_search_for_direct_origin_and_extras(
 
 
 @pytest.mark.parametrize("value", [True, False])
-def test_search_for_vcs_retains_develop_flag(provider: Provider, value: bool):
+def test_search_for_vcs_retains_develop_flag(provider: Provider, value: bool) -> None:
     dependency = VCSDependency(
         "demo", "git", "https://github.com/demo/demo.git", develop=value
     )
@@ -175,7 +168,7 @@ def test_search_for_vcs_retains_develop_flag(provider: Provider, value: bool):
     assert package.develop == value
 
 
-def test_search_for_vcs_setup_egg_info(provider: Provider):
+def test_search_for_vcs_setup_egg_info(provider: Provider) -> None:
     dependency = VCSDependency("demo", "git", "https://github.com/demo/demo.git")
 
     package = provider.search_for_direct_origin_dependency(dependency)
@@ -193,7 +186,7 @@ def test_search_for_vcs_setup_egg_info(provider: Provider):
     }
 
 
-def test_search_for_vcs_setup_egg_info_with_extras(provider: Provider):
+def test_search_for_vcs_setup_egg_info_with_extras(provider: Provider) -> None:
     dependency = VCSDependency(
         "demo", "git", "https://github.com/demo/demo.git", extras=["foo"]
     )
@@ -213,7 +206,7 @@ def test_search_for_vcs_setup_egg_info_with_extras(provider: Provider):
     }
 
 
-def test_search_for_vcs_read_setup(provider: Provider, mocker: MockerFixture):
+def test_search_for_vcs_read_setup(provider: Provider, mocker: MockerFixture) -> None:
     mocker.patch("poetry.utils.env.EnvManager.get", return_value=MockEnv())
 
     dependency = VCSDependency("demo", "git", "https://github.com/demo/demo.git")
@@ -235,7 +228,7 @@ def test_search_for_vcs_read_setup(provider: Provider, mocker: MockerFixture):
 
 def test_search_for_vcs_read_setup_with_extras(
     provider: Provider, mocker: MockerFixture
-):
+) -> None:
     mocker.patch("poetry.utils.env.EnvManager.get", return_value=MockEnv())
 
     dependency = VCSDependency(
@@ -255,7 +248,7 @@ def test_search_for_vcs_read_setup_with_extras(
 
 def test_search_for_vcs_read_setup_raises_error_if_no_version(
     provider: Provider, mocker: MockerFixture
-):
+) -> None:
     mocker.patch(
         "poetry.inspection.info.get_pep517_metadata",
         return_value=PackageInfo(name="demo", version=None),
@@ -268,15 +261,12 @@ def test_search_for_vcs_read_setup_raises_error_if_no_version(
 
 
 @pytest.mark.parametrize("directory", ["demo", "non-canonical-name"])
-def test_search_for_directory_setup_egg_info(provider: Provider, directory: str):
+def test_search_for_directory_setup_egg_info(
+    provider: Provider, directory: str, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = DirectoryDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "git"
-        / "github.com"
-        / "demo"
-        / directory,
+        fixture_dir("git") / "github.com" / "demo" / directory,
     )
 
     package = provider.search_for_direct_origin_dependency(dependency)
@@ -294,15 +284,12 @@ def test_search_for_directory_setup_egg_info(provider: Provider, directory: str)
     }
 
 
-def test_search_for_directory_setup_egg_info_with_extras(provider: Provider):
+def test_search_for_directory_setup_egg_info_with_extras(
+    provider: Provider, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = DirectoryDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "git"
-        / "github.com"
-        / "demo"
-        / "demo",
+        fixture_dir("git") / "github.com" / "demo" / "demo",
         extras=["foo"],
     )
 
@@ -322,21 +309,13 @@ def test_search_for_directory_setup_egg_info_with_extras(provider: Provider):
 
 
 @pytest.mark.parametrize("directory", ["demo", "non-canonical-name"])
-def test_search_for_directory_setup_with_base(provider: Provider, directory: str):
+def test_search_for_directory_setup_with_base(
+    provider: Provider, directory: str, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = DirectoryDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "git"
-        / "github.com"
-        / "demo"
-        / directory,
-        base=Path(__file__).parent.parent
-        / "fixtures"
-        / "git"
-        / "github.com"
-        / "demo"
-        / directory,
+        fixture_dir("git") / "github.com" / "demo" / directory,
+        base=fixture_dir("git") / "github.com" / "demo" / directory,
     )
 
     package = provider.search_for_direct_origin_dependency(dependency)
@@ -352,29 +331,17 @@ def test_search_for_directory_setup_with_base(provider: Provider, directory: str
         "foo": [get_dependency("cleo")],
         "bar": [get_dependency("tomlkit")],
     }
-    assert package.root_dir == (
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "git"
-        / "github.com"
-        / "demo"
-        / directory
-    )
+    assert package.root_dir == (fixture_dir("git") / "github.com" / "demo" / directory)
 
 
 def test_search_for_directory_setup_read_setup(
-    provider: Provider, mocker: MockerFixture
-):
+    provider: Provider, mocker: MockerFixture, fixture_dir: FixtureDirGetter
+) -> None:
     mocker.patch("poetry.utils.env.EnvManager.get", return_value=MockEnv())
 
     dependency = DirectoryDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "git"
-        / "github.com"
-        / "demo"
-        / "demo",
+        fixture_dir("git") / "github.com" / "demo" / "demo",
     )
 
     package = provider.search_for_direct_origin_dependency(dependency)
@@ -393,18 +360,13 @@ def test_search_for_directory_setup_read_setup(
 
 
 def test_search_for_directory_setup_read_setup_with_extras(
-    provider: Provider, mocker: MockerFixture
-):
+    provider: Provider, mocker: MockerFixture, fixture_dir: FixtureDirGetter
+) -> None:
     mocker.patch("poetry.utils.env.EnvManager.get", return_value=MockEnv())
 
     dependency = DirectoryDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "git"
-        / "github.com"
-        / "demo"
-        / "demo",
+        fixture_dir("git") / "github.com" / "demo" / "demo",
         extras=["foo"],
     )
 
@@ -423,15 +385,12 @@ def test_search_for_directory_setup_read_setup_with_extras(
     }
 
 
-def test_search_for_directory_setup_read_setup_with_no_dependencies(provider: Provider):
+def test_search_for_directory_setup_read_setup_with_no_dependencies(
+    provider: Provider, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = DirectoryDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "git"
-        / "github.com"
-        / "demo"
-        / "no-dependencies",
+        fixture_dir("git") / "github.com" / "demo" / "no-dependencies",
     )
 
     package = provider.search_for_direct_origin_dependency(dependency)
@@ -442,10 +401,12 @@ def test_search_for_directory_setup_read_setup_with_no_dependencies(provider: Pr
     assert package.extras == {}
 
 
-def test_search_for_directory_poetry(provider: Provider):
+def test_search_for_directory_poetry(
+    provider: Provider, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = DirectoryDependency(
         "project-with-extras",
-        Path(__file__).parent.parent / "fixtures" / "project_with_extras",
+        fixture_dir("project_with_extras"),
     )
 
     package = provider.search_for_direct_origin_dependency(dependency)
@@ -470,10 +431,12 @@ def test_search_for_directory_poetry(provider: Provider):
     }
 
 
-def test_search_for_directory_poetry_with_extras(provider: Provider):
+def test_search_for_directory_poetry_with_extras(
+    provider: Provider, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = DirectoryDependency(
         "project-with-extras",
-        Path(__file__).parent.parent / "fixtures" / "project_with_extras",
+        fixture_dir("project_with_extras"),
         extras=["extras_a"],
     )
 
@@ -499,13 +462,12 @@ def test_search_for_directory_poetry_with_extras(provider: Provider):
     }
 
 
-def test_search_for_file_sdist(provider: Provider):
+def test_search_for_file_sdist(
+    provider: Provider, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = FileDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "distributions"
-        / "demo-0.1.0.tar.gz",
+        fixture_dir("distributions") / "demo-0.1.0.tar.gz",
     )
 
     package = provider.search_for_direct_origin_dependency(dependency)
@@ -530,13 +492,12 @@ def test_search_for_file_sdist(provider: Provider):
     }
 
 
-def test_search_for_file_sdist_with_extras(provider: Provider):
+def test_search_for_file_sdist_with_extras(
+    provider: Provider, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = FileDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "distributions"
-        / "demo-0.1.0.tar.gz",
+        fixture_dir("distributions") / "demo-0.1.0.tar.gz",
         extras=["foo"],
     )
 
@@ -562,13 +523,12 @@ def test_search_for_file_sdist_with_extras(provider: Provider):
     }
 
 
-def test_search_for_file_wheel(provider: Provider):
+def test_search_for_file_wheel(
+    provider: Provider, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = FileDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "distributions"
-        / "demo-0.1.0-py2.py3-none-any.whl",
+        fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl",
     )
 
     package = provider.search_for_direct_origin_dependency(dependency)
@@ -593,13 +553,12 @@ def test_search_for_file_wheel(provider: Provider):
     }
 
 
-def test_search_for_file_wheel_with_extras(provider: Provider):
+def test_search_for_file_wheel_with_extras(
+    provider: Provider, fixture_dir: FixtureDirGetter
+) -> None:
     dependency = FileDependency(
         "demo",
-        Path(__file__).parent.parent
-        / "fixtures"
-        / "distributions"
-        / "demo-0.1.0-py2.py3-none-any.whl",
+        fixture_dir("distributions") / "demo-0.1.0-py2.py3-none-any.whl",
         extras=["foo"],
     )
 
@@ -649,10 +608,9 @@ def test_complete_package_does_not_merge_different_source_names(
 
 
 def test_complete_package_preserves_source_type(
-    provider: Provider, root: ProjectPackage
+    provider: Provider, root: ProjectPackage, fixture_dir: FixtureDirGetter
 ) -> None:
-    fixtures = Path(__file__).parent.parent / "fixtures"
-    project_dir = fixtures.joinpath("with_conditional_path_deps")
+    project_dir = fixture_dir("with_conditional_path_deps")
     for folder in ["demo_one", "demo_two"]:
         path = (project_dir / folder).as_posix()
         root.add_dependency(Factory.create_dependency("demo", {"path": path}))
@@ -724,7 +682,7 @@ def test_complete_package_with_extras_preserves_source_name(
     package_b = Package("B", "1.0")
     dep = get_dependency("B", "^1.0", optional=True)
     package_a.add_dependency(dep)
-    package_a.extras = {"foo": [dep]}
+    package_a.extras = {canonicalize_name("foo"): [dep]}
     repository.add_package(package_a)
     repository.add_package(package_b)
 
@@ -747,13 +705,13 @@ def test_complete_package_with_extras_preserves_source_name(
 @pytest.mark.parametrize("with_extra", [False, True])
 def test_complete_package_fetches_optional_vcs_dependency_only_if_requested(
     provider: Provider, repository: Repository, mocker: MockerFixture, with_extra: bool
-):
+) -> None:
     optional_vcs_dependency = Factory.create_dependency(
         "demo", {"git": "https://github.com/demo/demo.git", "optional": True}
     )
     package = Package("A", "1.0", features=["foo"] if with_extra else [])
     package.add_dependency(optional_vcs_dependency)
-    package.extras["foo"] = [optional_vcs_dependency]
+    package.extras[canonicalize_name("foo")] = [optional_vcs_dependency]
     repository.add_package(package)
 
     spy = mocker.spy(provider, "_search_for_vcs")
