@@ -42,12 +42,12 @@ def mock_remote(http: type[httpretty.httpretty]) -> None:
 
 
 @pytest.fixture()
-def repo():
+def repo() -> dict[str, dict[str, str]]:
     return {"foo": {"url": "https://foo.bar/simple/"}}
 
 
 @pytest.fixture
-def mock_config(config: Config, repo: dict[str, dict[str, str]]):
+def mock_config(config: Config, repo: dict[str, dict[str, str]]) -> Config:
     config.merge(
         {
             "repositories": repo,
@@ -60,7 +60,7 @@ def mock_config(config: Config, repo: dict[str, dict[str, str]]):
 
 def test_authenticator_uses_url_provided_credentials(
     mock_config: Config, mock_remote: None, http: type[httpretty.httpretty]
-):
+) -> None:
     authenticator = Authenticator(mock_config, NullIO())
     authenticator.request("get", "https://foo001:bar002@foo.bar/files/foo-0.1.0.tar.gz")
 
@@ -71,7 +71,7 @@ def test_authenticator_uses_url_provided_credentials(
 
 def test_authenticator_uses_credentials_from_config_if_not_provided(
     mock_config: Config, mock_remote: None, http: type[httpretty.httpretty]
-):
+) -> None:
     authenticator = Authenticator(mock_config, NullIO())
     authenticator.request("get", "https://foo.bar/files/foo-0.1.0.tar.gz")
 
@@ -85,7 +85,7 @@ def test_authenticator_uses_username_only_credentials(
     mock_remote: None,
     http: type[httpretty.httpretty],
     with_simple_keyring: None,
-):
+) -> None:
     authenticator = Authenticator(mock_config, NullIO())
     authenticator.request("get", "https://foo001@foo.bar/files/foo-0.1.0.tar.gz")
 
@@ -96,7 +96,7 @@ def test_authenticator_uses_username_only_credentials(
 
 def test_authenticator_uses_password_only_credentials(
     mock_config: Config, mock_remote: None, http: type[httpretty.httpretty]
-):
+) -> None:
     authenticator = Authenticator(mock_config, NullIO())
     authenticator.request("get", "https://:bar002@foo.bar/files/foo-0.1.0.tar.gz")
 
@@ -111,7 +111,7 @@ def test_authenticator_uses_empty_strings_as_default_password(
     repo: dict[str, dict[str, str]],
     http: type[httpretty.httpretty],
     with_simple_keyring: None,
-):
+) -> None:
     config.merge(
         {
             "repositories": repo,
@@ -132,7 +132,7 @@ def test_authenticator_uses_empty_strings_as_default_username(
     mock_remote: None,
     repo: dict[str, dict[str, str]],
     http: type[httpretty.httpretty],
-):
+) -> None:
     config.merge(
         {
             "repositories": repo,
@@ -155,7 +155,7 @@ def test_authenticator_falls_back_to_keyring_url(
     http: type[httpretty.httpretty],
     with_simple_keyring: None,
     dummy_keyring: DummyBackend,
-):
+) -> None:
     config.merge(
         {
             "repositories": repo,
@@ -163,7 +163,7 @@ def test_authenticator_falls_back_to_keyring_url(
     )
 
     dummy_keyring.set_password(
-        "https://foo.bar/simple/", None, SimpleCredential(None, "bar")
+        "https://foo.bar/simple/", None, SimpleCredential("foo", "bar")
     )
 
     authenticator = Authenticator(config, NullIO())
@@ -171,7 +171,7 @@ def test_authenticator_falls_back_to_keyring_url(
 
     request = http.last_request()
 
-    assert request.headers["Authorization"] == "Basic OmJhcg=="
+    assert request.headers["Authorization"] == "Basic Zm9vOmJhcg=="
 
 
 def test_authenticator_falls_back_to_keyring_netloc(
@@ -181,41 +181,41 @@ def test_authenticator_falls_back_to_keyring_netloc(
     http: type[httpretty.httpretty],
     with_simple_keyring: None,
     dummy_keyring: DummyBackend,
-):
+) -> None:
     config.merge(
         {
             "repositories": repo,
         }
     )
 
-    dummy_keyring.set_password("foo.bar", None, SimpleCredential(None, "bar"))
+    dummy_keyring.set_password("foo.bar", None, SimpleCredential("foo", "bar"))
 
     authenticator = Authenticator(config, NullIO())
     authenticator.request("get", "https://foo.bar/files/foo-0.1.0.tar.gz")
 
     request = http.last_request()
 
-    assert request.headers["Authorization"] == "Basic OmJhcg=="
+    assert request.headers["Authorization"] == "Basic Zm9vOmJhcg=="
 
 
 @pytest.mark.filterwarnings("ignore::pytest.PytestUnhandledThreadExceptionWarning")
 def test_authenticator_request_retries_on_exception(
     mocker: MockerFixture, config: Config, http: type[httpretty.httpretty]
-):
+) -> None:
     sleep = mocker.patch("time.sleep")
     sdist_uri = f"https://foo.bar/files/{uuid.uuid4()!s}/foo-0.1.0.tar.gz"
     content = str(uuid.uuid4())
-    seen = []
+    seen: list[str] = []
 
     def callback(
-        request: requests.Request, uri: str, response_headers: dict
-    ) -> list[int | dict | str]:
+        request: requests.Request, uri: str, response_headers: dict[str, str]
+    ) -> list[int | dict[str, str] | str]:
         if seen.count(uri) < 2:
             seen.append(uri)
             raise requests.exceptions.ConnectionError("Disconnected")
         return [200, response_headers, content]
 
-    httpretty.register_uri(httpretty.GET, sdist_uri, body=callback)
+    http.register_uri(httpretty.GET, sdist_uri, body=callback)
 
     authenticator = Authenticator(config, NullIO())
     response = authenticator.request("get", sdist_uri)
@@ -226,14 +226,14 @@ def test_authenticator_request_retries_on_exception(
 @pytest.mark.filterwarnings("ignore::pytest.PytestUnhandledThreadExceptionWarning")
 def test_authenticator_request_raises_exception_when_attempts_exhausted(
     mocker: MockerFixture, config: Config, http: type[httpretty.httpretty]
-):
+) -> None:
     sleep = mocker.patch("time.sleep")
     sdist_uri = f"https://foo.bar/files/{uuid.uuid4()!s}/foo-0.1.0.tar.gz"
 
     def callback(*_: Any, **___: Any) -> None:
         raise requests.exceptions.ConnectionError(str(uuid.uuid4()))
 
-    httpretty.register_uri(httpretty.GET, sdist_uri, body=callback)
+    http.register_uri(httpretty.GET, sdist_uri, body=callback)
     authenticator = Authenticator(config, NullIO())
 
     with pytest.raises(requests.exceptions.ConnectionError):
@@ -242,6 +242,33 @@ def test_authenticator_request_raises_exception_when_attempts_exhausted(
     assert sleep.call_count == 5
 
 
+def test_authenticator_request_respects_retry_header(
+    mocker: MockerFixture,
+    config: Config,
+    http: type[httpretty.httpretty],
+) -> None:
+    sleep = mocker.patch("time.sleep")
+    sdist_uri = f"https://foo.bar/files/{uuid.uuid4()!s}/foo-0.1.0.tar.gz"
+    content = str(uuid.uuid4())
+    seen: list[str] = []
+
+    def callback(
+        request: requests.Request, uri: str, response_headers: dict[str, str]
+    ) -> list[int | dict[str, str] | str]:
+        if not seen.count(uri):
+            seen.append(uri)
+            return [429, {"Retry-After": "42"}, "Retry later"]
+
+        return [200, response_headers, content]
+
+    http.register_uri(httpretty.GET, sdist_uri, body=callback)
+    authenticator = Authenticator(config, NullIO())
+
+    response = authenticator.request("get", sdist_uri)
+    assert sleep.call_args[0] == (42.0,)
+    assert response.text == content
+
+
 @pytest.mark.parametrize(
     ["status", "attempts"],
     [
@@ -249,7 +276,9 @@ def test_authenticator_request_raises_exception_when_attempts_exhausted(
         (401, 0),
         (403, 0),
         (404, 0),
-        (500, 0),
+        (429, 5),
+        (500, 5),
+        (501, 5),
         (502, 5),
         (503, 5),
         (504, 5),
@@ -261,17 +290,17 @@ def test_authenticator_request_retries_on_status_code(
     http: type[httpretty.httpretty],
     status: int,
     attempts: int,
-):
+) -> None:
     sleep = mocker.patch("time.sleep")
     sdist_uri = f"https://foo.bar/files/{uuid.uuid4()!s}/foo-0.1.0.tar.gz"
     content = str(uuid.uuid4())
 
     def callback(
-        request: requests.Request, uri: str, response_headers: dict
-    ) -> list[int | dict | str]:
+        request: requests.Request, uri: str, response_headers: dict[str, str]
+    ) -> list[int | dict[str, str] | str]:
         return [status, response_headers, content]
 
-    httpretty.register_uri(httpretty.GET, sdist_uri, body=callback)
+    http.register_uri(httpretty.GET, sdist_uri, body=callback)
     authenticator = Authenticator(config, NullIO())
 
     with pytest.raises(requests.exceptions.HTTPError) as excinfo:
@@ -290,7 +319,7 @@ def test_authenticator_uses_env_provided_credentials(
     mock_remote: type[httpretty.httpretty],
     http: type[httpretty.httpretty],
     monkeypatch: MonkeyPatch,
-):
+) -> None:
     monkeypatch.setenv("POETRY_HTTP_BASIC_FOO_USERNAME", "bar")
     monkeypatch.setenv("POETRY_HTTP_BASIC_FOO_PASSWORD", "baz")
 
@@ -321,7 +350,7 @@ def test_authenticator_uses_certs_from_config_if_not_provided(
     mocker: MockerFixture,
     cert: str | None,
     client_cert: str | None,
-):
+) -> None:
     configured_cert = "/path/to/cert"
     configured_client_cert = "/path/to/client-cert"
 
@@ -351,7 +380,7 @@ def test_authenticator_uses_certs_from_config_if_not_provided(
 
 def test_authenticator_uses_credentials_from_config_matched_by_url_path(
     config: Config, mock_remote: None, http: type[httpretty.httpretty]
-):
+) -> None:
     config.merge(
         {
             "repositories": {
@@ -384,7 +413,7 @@ def test_authenticator_uses_credentials_from_config_matched_by_url_path(
 
 def test_authenticator_uses_credentials_from_config_with_at_sign_in_path(
     config: Config, mock_remote: None, http: type[httpretty.httpretty]
-):
+) -> None:
     config.merge(
         {
             "repositories": {
@@ -410,7 +439,7 @@ def test_authenticator_falls_back_to_keyring_url_matched_by_path(
     http: type[httpretty.httpretty],
     with_simple_keyring: None,
     dummy_keyring: DummyBackend,
-):
+) -> None:
     config.merge(
         {
             "repositories": {
@@ -421,10 +450,10 @@ def test_authenticator_falls_back_to_keyring_url_matched_by_path(
     )
 
     dummy_keyring.set_password(
-        "https://foo.bar/alpha/files/simple/", None, SimpleCredential(None, "bar")
+        "https://foo.bar/alpha/files/simple/", None, SimpleCredential("foo", "bar")
     )
     dummy_keyring.set_password(
-        "https://foo.bar/beta/files/simple/", None, SimpleCredential(None, "baz")
+        "https://foo.bar/beta/files/simple/", None, SimpleCredential("foo", "baz")
     )
 
     authenticator = Authenticator(config, NullIO())
@@ -432,13 +461,13 @@ def test_authenticator_falls_back_to_keyring_url_matched_by_path(
     authenticator.request("get", "https://foo.bar/alpha/files/simple/foo-0.1.0.tar.gz")
     request = http.last_request()
 
-    basic_auth = base64.b64encode(b":bar").decode()
+    basic_auth = base64.b64encode(b"foo:bar").decode()
     assert request.headers["Authorization"] == f"Basic {basic_auth}"
 
     authenticator.request("get", "https://foo.bar/beta/files/simple/foo-0.1.0.tar.gz")
     request = http.last_request()
 
-    basic_auth = base64.b64encode(b":baz").decode()
+    basic_auth = base64.b64encode(b"foo:baz").decode()
     assert request.headers["Authorization"] == f"Basic {basic_auth}"
 
 
@@ -448,7 +477,7 @@ def test_authenticator_uses_env_provided_credentials_matched_by_url_path(
     mock_remote: type[httpretty.httpretty],
     http: type[httpretty.httpretty],
     monkeypatch: MonkeyPatch,
-):
+) -> None:
     monkeypatch.setenv("POETRY_HTTP_BASIC_FOO_ALPHA_USERNAME", "bar")
     monkeypatch.setenv("POETRY_HTTP_BASIC_FOO_ALPHA_PASSWORD", "alpha")
     monkeypatch.setenv("POETRY_HTTP_BASIC_FOO_BETA_USERNAME", "baz")
@@ -484,7 +513,7 @@ def test_authenticator_azure_feed_guid_credentials(
     http: type[httpretty.httpretty],
     with_simple_keyring: None,
     dummy_keyring: DummyBackend,
-):
+) -> None:
     config.merge(
         {
             "repositories": {
@@ -529,7 +558,7 @@ def test_authenticator_add_repository(
     http: type[httpretty.httpretty],
     with_simple_keyring: None,
     dummy_keyring: DummyBackend,
-):
+) -> None:
     config.merge(
         {
             "http-basic": {
@@ -565,7 +594,7 @@ def test_authenticator_git_repositories(
     http: type[httpretty.httpretty],
     with_simple_keyring: None,
     dummy_keyring: DummyBackend,
-):
+) -> None:
     config.merge(
         {
             "repositories": {
@@ -598,6 +627,22 @@ def test_authenticator_git_repositories(
     assert not three.password
 
 
+def test_authenticator_get_cached_file_for_url__cache_miss(config: Config) -> None:
+    authenticator = Authenticator(config, NullIO())
+    assert (
+        authenticator.get_cached_file_for_url("https://foo.bar/cache/miss.whl") is None
+    )
+
+
+def test_authenticator_get_cached_file_for_url__cache_hit(config: Config) -> None:
+    authenticator = Authenticator(config, NullIO())
+    url = "https://foo.bar/files/foo-0.1.0.tar.gz"
+
+    authenticator._cache_control.set(url, b"hello")
+
+    assert authenticator.get_cached_file_for_url(url)
+
+
 @pytest.mark.parametrize(
     ("ca_cert", "client_cert", "result"),
     [
